aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--libbuild2/parser.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/libbuild2/parser.cxx b/libbuild2/parser.cxx
index 53ff7f7..cda4c69 100644
--- a/libbuild2/parser.cxx
+++ b/libbuild2/parser.cxx
@@ -2765,9 +2765,9 @@ namespace build2
fail (l) << "invalid module version '" << i->value << "': " << e;
}
// Handle the special 'build' module.
//
- if (n == "build")
+ if (n == "build2" || n == "build")
{
if (v)
{
@@ -2765,9 +2765,9 @@ namespace build2
fail (l) << "invalid module version '" << i->value << "': " << e;
}
- // Handle the special 'build' module.
+ // Handle the special 'build' and 'build2' modules.
//